function display_QC( hGUI, hAxes )
%
% Function to plot the Water Sample measurements
%
% Input
% -----
% hGUI ............... Handel to the user interface
% hAxes .............. Handels to the graphic axes
%
% Output
% ------
% $Id$

% Retrieve named application data
% -------------------------------
tsg    = getappdata( hGUI, 'tsg_data');

% get panel handle
% ----------------
hdlPanel = findobj(hGUI, 'tag', 'TAG_QC_DISPLAY_PANEL');

% get color axes and set 'BackgroundColor' properties of panel handle
% give a transparency effect
% -------------------------------------------------------------------
bgColor = get(hAxes(1), 'Color');
set(hdlPanel, 'BackgroundColor', bgColor);

% and to his chlidren uicontrol 
% -----------------------------
set(findobj(get(hdlPanel,'children'),'style','text'),...
   'BackgroundColor', bgColor)

% set panel visible
% -----------------
set(hdlPanel, 'visible', 'on');

% get list of keys from hashtable tsg.qc.hash, defined inside
% tsg_initialisation.m
% -----------------------------------------------------------
qc_list = get(tsg.qc.hash);

% iterate (loop) on each key store inside hastable
% ------------------------------------------------
for i=1:numel(qc_list)
  
  % get key and some values in hashtable
  % ------------------------------------
  key   = qc_list{i};
  code = get(tsg.qc.hash, key, 'code');
  
  % get the uicontrol handle from tag construct with key
  % ----------------------------------------------------
  hdlText = findobj(hGUI, 'tag', ['TAG_QC_TEXT_' key]);
  
  % find number of sample flag with this QC code
  % --------------------------------------------
  ind = find(tsg.SSPS_QC == code);
  
  % if index empty, no data with this flag, set field to zero (char)
  % ----------------------------------------------------------------
  if isempty(ind)
    set(hdlText, 'String', '0');
  else
    set(hdlText, 'String', num2str(numel(ind)));
  end
  
end

           
